<?
	/**
	 *	Title: Classe Boletu, model per a un bolet.
	 *
	 *	Project: iBoletus
	 *	Author: Victor Llorente Vaquero
	 *	Date: 20/11/2013
	 *	Email: vllorente@uoc.edu
	 **/
	
	class Boletu {
	
		private $bol_id;
		private $bol_usr_id;
		private $bol_name;
		private $bol_name_latin;
		private $bol_toxic;
		private $bol_description;
		private $bol_habitat;
		private $bol_observation;
		
		private $user;
				
		private $db = null;
		private $dbConn = null;
		
		public function __construct($db) {
			$this->db = $db;
			$this->dbConn = $this->db->getDB();
			
			$this->user = new User($this->db);
		}
		
		public function initWithId($id) {
			try {
				$stmt = $this->dbConn->prepare("select * from boletus where bol_id = :id limit 1");
				$stmt->execute(array('id' => $id));
			} catch (PDOException $e) { $this->db->getError($e); }
			
			if ($stmt->rowCount() == 1) $this->fill($stmt->fetch());
			
			$this->user->initWithId($this->bol_usr_id);
		}
		
		public function initWithArray(array $data) {
			if (is_array($data) && !empty($data)) $this->fill($data);
		}
	
		public function saveToDB(){
			try {
				$stmt = $this->dbConn->prepare("insert into boletus (bol_usr_id, bol_name, bol_name_latin, bol_toxic, bol_description, bol_habitat, bol_observation) values (:bol_usr_id, :bol_name, :bol_name_latin, :bol_toxic, :bol_description, :bol_habitat, :bol_observation)");
				$stmt->execute(array('bol_usr_id' => $_SESSION[info_user][id], 'bol_name' => $this->bol_name, 'bol_name_latin' => $this->bol_name_latin, 'bol_toxic' => $this->bol_toxic, 'bol_description' => $this->bol_description, 'bol_habitat' => $this->bol_habitat, 'bol_observation' => $this->bol_observation));
				$id = $this->dbConn->lastInsertId();
			} catch (PDOException $e) { $this->db->getError($e); }
			
			return $id;
		}

		public function updateInDB() {
			try {
				$params = array('bol_name' => $this->bol_name, 'bol_name_latin' => $this->bol_name_latin, 'bol_toxic' => $this->bol_toxic, 'bol_description' => $this->bol_description, 'bol_habitat' => $this->bol_habitat, 'bol_observation' =>  $this->bol_observation, 'bol_id' => $this->bol_id);
				$query = "update boletus set bol_name = :bol_name, bol_name_latin = :bol_name_latin, bol_toxic = :bol_toxic, bol_description = :bol_description, bol_habitat = :bol_habitat, bol_observation = :bol_observation where bol_id = :bol_id";
				$stmt = $this->dbConn->prepare($query);
				$stmt->execute($params);
			} catch (PDOException $e) { $this->db->getError($e); }
		}
		
		public function deleteFromDB() {
			try {
				$stmt = $this->dbConn->prepare("delete from boletus where bol_id = :id");
				$stmt->execute(array('id' => $this->bol_id));
			} catch (PDOException $e) { $this->db->getError($e); }
		}
		
		public function isNotEmpty() { return isset($this->bol_id); }
		
		// Gets
		public function getBoletuId() { return $this->bol_id; }
		public function getBoletuUserId() { return $this->bol_usr_id; }
		public function getBoletuUserFullName() { return $this->user->getUserFullName(); }
		public function getBoletuName() { return $this->bol_name; }
		public function getBoletuNameLatin() { return $this->bol_name_latin; }
		public function getBoletuFullName() { if (!empty($this->bol_name_latin)) return $this->bol_name." (".$this->bol_name_latin.")"; else return $this->bol_name; }
		public function getBoletuToxic() { return $this->bol_toxic; }
		public function getBoletuDescription() { return $this->bol_description; }
		public function getBoletuHabitat() { return $this->bol_habitat; }
		public function getBoletuObservation() { return $this->bol_observation; }
		
		// Sets
		public function setBoletuId($value) { $this->bol_id = $value; }
		public function setBoletuName($value) { $this->bol_name = $value; }
		public function setBoletuNameLatin($value) { $this->bol_name_latin = $value; }
		public function setBoletuToxic($value) { $this->bol_toxic = $value; }
		public function setBoletuDescription($value) { $this->bol_description = $value; }
		public function setBoletuHabitat($value) { $this->bol_habitat = $value; }
		public function setBoletuObservation($value) { $this->bol_observation = $value; }
		
		protected function fill(array $row){
			foreach ($row as $propName => $propValue) $this->{$propName} = $propValue;
		}
	}
	
?>