<?
	/**
	 *	Title: Classe Error, gestiona els missatges d'error així com les notificacions.
	 *
	 *	Project: iBoletus
	 *	Author: Victor Llorente Vaquero
	 *	Date: 18/11/2013
	 *	Email: vllorente@uoc.edu
	 **/
	
	require_once(DIRLIB."/send_mail.php");
	
	class Error {
		
		private $error_number;
		private $info;
		
		private $db = null;
		private $dbConn = null;
		
		public function __construct() {
			$this->db = new Database();
			$this->dbConn = $this->db->getDB();
		}
		
		public function showError($error_num, $info = "") {
			
			$this->error_number = $error_num;
			$this->info = $info;
			
			switch($this->error_number) {
				case ERROR_DB:
					$action = "query_error"; 
					$header = "Error de comunicació amb la base de dades"; 
					$html_text = "S'ha produït un error de comunicació amb la base de dades. Si us plau, contacteu amb l'administrador."; 
					break;
				case ERROR_PERMISSION: 
					$action = "permission_error"; 
					$header = "Accés no autoritzat"; 
					$html_text = "No teniu els permisos necessaris per accedir a aquesta pàgina. Si us plau, contacteu amb l'administrador.";
					break;
				case ERROR_UPLOAD:
					$action = "upload_error"; 
					$header = "Error en la pujada d'un arxiu"; 
					$html_text = "S'ha produït un error al pujar un arxiu. Verifica la mida (màxim ".FILE_SIZE." B).";
					break;
				case ERROR_UPLOAD_IMAGE:
					$action = "upload_image_error";
					$header = "Error en la pujada d'una imatge"; 
					$html_text = "S'ha produït un error al pujar una imatge. Verifica la mida (màxim ".COVER_SIZE." B) i que el format sigui JPG.";
					break;
				case ERROR_NOT_FOUND:
					$action = "url_not_found"; 
					$header = "Error 404: El recurs sol·licitat no existeix";
					$html_text = "S'ha produït el següent error a l'accedir a la pàgina sol·licitada: no existeix. Si us plau, contacteu amb l'administrador."; 
					break;
				case ERROR_ACCESS_FORBIDDEN: 
					$action = "url_access_denied"; 
					$header = "Error 403: No teniu privilegis d'accés al recurs sol·licitat";
					$html_text = "S'ha produït el següent error a l'accedir a la pàgina sol·licitada: no teniu privilegis per accedir-hi. Si us plau, contacteu amb l'administrador."; 
					break;
				case ERROR_TAMPERED_DATA: 
					$action = "tampered_data_error"; 
					$header = "Error fatal en la comprovació de les dades entrades";
					$html_text = "S'ha produït el següent error a l'accedir a la pàgina sol·licitada: les dades enviades al servidor eren errònies. Si us plau, contacteu amb l'administrador."; 
					break;
				case ERROR_FILE_NOT_FOUND: 
					$action = "file_not_found_error"; 
					$header = "Error en la descarrega d'un arxiu";
					$html_text = "S'ha produït el següent error a l'accedir a la pàgina sol·licitada: l'arxiu no existeix. Si us plau, contacteu amb l'administrador."; 
					break;
			}
	
			$c = new Content();
			$c->getErrorPage($header, $html_text);
			
			if (($this->error_number != ERROR_NOT_FOUND) && ($this->error_number != ERROR_ACCESS_FORBIDDEN) && ($this->error_number != ERROR_UPLOAD_IMAGE) && ($this->error_number != ERROR_UPLOAD)) {
				$this->sendErrorMail();
			}
			exit;
		}
	
		private function sendErrorMail() {
	
			$mail_to_name = "[".APP."-dev]";
			$date = date("c", time());
			$session_data = print_r($_SESSION['info_user'], true);
			
			switch($this->error_number) {
				case ERROR_DB: 
					$mail_to = MAIL_DEV;
					$subject = "[".APP."]: Error de consulta a la base de dades.";
					$html_text = "<html><body>S'ha produït un error en fer una consulta a la base de dades.<br><br>Data: ".format_date_hour($date)."<br><br>L'error ha estat el següent:<br><br>".$this->info;
					$mail_text = "S'ha produït un error en fer una consulta a la base de dades.\n\nData: ".format_date_hour($date)."\n\nL'error ha estat el següent:\n\n".$this->info;
					break;
				case ERROR_PERMISSION:
					$mail_to = MAIL_DEV;
					$subject = "[".APP."]: Error de permisos.";
					$html_text = "<html><body>S'ha produït un error de permisos.<br><br>Data: >".format_date_hour($date); 
					$mail_text = "S'ha produït un error de permisos.\n\nData: ".format_date_hour($date);
					break;
				case ERROR_UPLOAD:
					$mail_to = MAIL_DEV;
					$subject = "[".APP."]: Error de carrega d'un arxiu.";
					$html_text = "<html><body>S'ha produït un error en la carrega d'un arxiu.<br><br>Data: ".format_date_hour($date);
					$mail_text = "S'ha produït un error en la carrega d'un arxiu.\n\nData: ".format_date_hour($date);
					break;
				case ERROR_CREATE_FOLDER: 
					$mail_to = MAIL_DEV;
					$subject = "[".APP."]: Error en crear la carpeta d'un usuari.";
					$html_text = "<html><body>S'ha produït un error en crear la carpeta d'un usuari.<br><br>Data: ".format_date_hour($date);
					$mail_text = "S'ha produït un error en crear la carpeta d'un usuari.\n\nData: ".format_date_hour($date);
					break;
				case ERROR_REPORT: 
					$mail_to = MAIL_REP;
					$subject = "[".APP."]: Error d'execució d'un llistat.";
					$html_text = "<html><body>S'ha produït un error en l'execució d'un llistat.<br><br>Data: ".format_date_hour($date)."<br><br>L'error que Java ha retornat és el següent:<br><br>".$this->info;
					$mail_text = "S'ha produït un error en l'execució d'un llistat.\n\nData: ".format_date_hour($date)."\n\nL'error que Java ha retornat és el següent:\n\n".$this->info;
					break;
				case ERROR_TAMPERED_DATA: 
					$mail_to = MAIL_DEV;
					$subject = "[".APP."]: Error en les dades rebudes.";
					$html_text = "<html><body>S'ha produït un error fatal de verificació de dades entrades.<br><br>Data: ".format_date_hour($date); 
					$mail_text = "S'ha produït un error fatal de verificació de dades entrades.\n\nData: ".format_date_hour($date);
					break;
				case ERROR_FILE_NOT_FOUND: 
					$mail_to = MAIL_DEV;
					$subject = "[".APP."]: Error al descarregar un arxiu.";
					$html_text = "<html><body>S'ha produït un error a l'hora de descarregar una arxiu.<br><br>Data: ".format_date_hour($date); 
					$mail_text = "S'ha produït un error fatal de verificació de dades entrades.\n\nData: ".format_date_hour($date);
					break;
			}
			
			$html_text .= "<br><br>La URL on s'ha produït l'error ha estat:<br><br>".WWWROOT.$_SERVER['REQUEST_URI']."<br><br>Les dades de sessió són:<br><br>".$session_data."</body></html>";
			$mail_text .= "\n\nLa URL on s'ha produït l'error ha estat:\n\n".WWWROOT.$_SERVER['REQUEST_URI']."\n\nLes dades de sessió són:\n\n".$session_data;
	
			if ($this->error_number != ERROR_DB) {
				try {
					$stmt = $this->dbConn->prepare("insert into mail_queue (mail_subject, mail_body, mail_alt_body, mail_to, mail_to_name, mail_date_created) values (:subject, :body, :text, :to, :name, :date)");
					$stmt->execute(array('subject' => $subject, 'body' => $html_text, 'text' => $mail_text, 'to' => $mail_to, 'name' => $mail_to_name, 'date' => $date));
				} catch (PDOException $e) {
					$this->showError(ERROR_DB, $e->getMessage());
				}
			} else {
				send_mail(MAIL_DEV, $mail_to_name, $subject, $html_text, $mail_text);			
			}
		}
	}
	
?>