<?
	/**
	 *	Title: Classe Position, model per a una posició.
	 *
	 *	Project: iBoletus
	 *	Author: Victor Llorente Vaquero
	 *	Date: 02/12/2013
	 *	Email: vllorente@uoc.edu
	 **/
	
	class Position {
	
		private $pos_id;
		private $pos_usr_id;
		private $pos_bol_id;
		private $pos_bol_name;
		private $pos_description;
		private $pos_lat;
		private $pos_lng;
		
		private $db = null;
		private $dbConn = null;
		
		public function __construct($db) {
			$this->db = $db;
			$this->dbConn = $this->db->getDB();
		}
		
		public function initWithId($id) {
			try {
				$stmt = $this->dbConn->prepare("select * from positions where pos_id = :id limit 1");
				$stmt->execute(array('id' => $id));
			} catch (PDOException $e) { $this->db->getError($e); }
			
			if ($stmt->rowCount() == 1) $this->fill($stmt->fetch());
		}
		
		public function initWithArray(array $data) {
			if (is_array($data) && !empty($data)) $this->fill($data);
		}
	
		public function saveToDB(){
			try {
				$stmt = $this->dbConn->prepare("insert into positions (pos_usr_id, pos_bol_id, pos_bol_name, pos_description, pos_lat, pos_lng) values (:pos_usr_id, :pos_bol_id, :pos_bol_name, :pos_description, :pos_lat, :pos_lng)");
				$stmt->execute(array('pos_usr_id' => $_SESSION[info_user][id], 'pos_bol_id' => $this->pos_bol_id, 'pos_bol_name' => $this->pos_bol_name, 'pos_description' => $this->pos_description, 'pos_lat' => $this->pos_lat, 'pos_lng' => $this->pos_lng));
				$id = $this->dbConn->lastInsertId();
			} catch (PDOException $e) { $this->db->getError($e); }
			
			return $id;
		}

		public function updateInDB() {
			try {
				$params = array('pos_bol_id' => $this->pos_bol_id, 'pos_bol_name' => $this->pos_bol_name, 'pos_description' => $this->pos_description, 'pos_id' => $this->pos_id);
				$query = "update positions set pos_bol_id = :pos_bol_id, pos_bol_name = :pos_bol_name, pos_description = :pos_description where pos_id = :pos_id";
				$stmt = $this->dbConn->prepare($query);
				$stmt->execute($params);
			} catch (PDOException $e) { $this->db->getError($e); }
		}
		
		public function deleteFromDB() {
			try {
				$stmt = $this->dbConn->prepare("delete from positions where pos_id = :id");
				$stmt->execute(array('id' => $this->pos_id));
			} catch (PDOException $e) { $this->db->getError($e); }
		}
		
		public function isNotEmpty() { return isset($this->pos_id); }
		
		// Gets
		public function getPositionId() { return $this->pos_id; }
		public function getPositionUserId() { return $this->pos_usr_id; }
		public function getPositionBoletuId() { return $this->pos_bol_id; }
		public function getPositionBoletuName() { return $this->pos_bol_name; }
		public function getPositionDescription() { return $this->pos_description; }
		public function getPositionLat() { return $this->pos_lat; }
		public function getPositionLng() { return $this->pos_lng; }
		
		// Sets
		public function setPositionId($value) { $this->pos_id = $value; }
		public function setPositionUserId($value) { $this->pos_usr_id = $value; }
		public function setPositionBoletuId($value) { $this->pos_bol_id = $value; }
		public function setPositionBoletuName($value) { $this->pos_bol_name = $value; }
		public function setPositionDescription($value) { $this->pos_description = $value; }
		public function setPositionLat($value) { $this->pos_lat = $value; }
		public function setPositionLng($value) { $this->pos_lng = $value; }
		
		protected function fill(array $row){
			foreach ($row as $propName => $propValue) $this->{$propName} = $propValue;
		}
	}
	
?>