<?
	/**
	 *	Title: Classe Recipe, model per a una recepta.
	 *
	 *	Project: iBoletus
	 *	Author: Víctor Llorente Vaquero
	 *	Date: 21/11/2013
	 *	Email: vllorente@uoc.edu
	 **/
	
	class Recipe {
	
		private $rec_id;
		private $rec_usr_id;
		private $rec_bol_id;
		private $rec_date;
		private $rec_name;
		private $rec_ingredient;
		private $rec_description;
		
		private $user;
		private $boletu;
				
		private $db = null;
		private $dbConn = null;
		
		public function __construct($db) {
			$this->db = $db;
			$this->dbConn = $this->db->getDB();
			
			$this->user = new User($this->db);
			$this->boletu = new Boletu($this->db);
		}
		
		public function initWithId($id) {
			try {
				$stmt = $this->dbConn->prepare("select * from recipes where rec_id = :id limit 1");
				$stmt->execute(array('id' => $id));
			} catch (PDOException $e) { $this->db->getError($e); }
			
			if ($stmt->rowCount() == 1) {
				$this->fill($stmt->fetch());
				$this->convertDates();
			}
			
			$this->user->initWithId($this->rec_usr_id);
			$this->boletu->initWithId($this->rec_bol_id);
		}
		
		protected function convertDates() {
			$this->rec_date = format_date_array($this->rec_date);
		}
		
		public function initWithArray(array $data) {
			if (is_array($data) && !empty($data)) $this->fill($data);
		}
	
		public function saveToDB() {
			try {
				$stmt = $this->dbConn->prepare("insert into recipes (rec_usr_id, rec_bol_id, rec_date, rec_name, rec_ingredient, rec_description) values (:rec_usr_id, :rec_bol_id, NOW(), :rec_name, :rec_ingredient, :rec_description)");
				$stmt->execute(array('rec_usr_id' => $_SESSION[info_user][id], 'rec_bol_id' => $this->rec_bol_id, 'rec_name' => $this->rec_name, 'rec_ingredient' => $this->rec_ingredient, 'rec_description' => $this->rec_description));
				$id = $this->dbConn->lastInsertId();
			} catch (PDOException $e) { $this->db->getError($e); }
			
			return $id;
		}

		public function updateInDB() {
			try {
				$params = array('rec_bol_id' => $this->rec_bol_id, 'rec_date' => get_ISO_date($this->rec_date), 'rec_name' => $this->rec_name, 'rec_ingredient' => $this->rec_ingredient, 'rec_description' => $this->rec_description, 'rec_id' => $this->rec_id);
				$query = "update recipes set rec_bol_id = :rec_bol_id, rec_date = :rec_date, rec_name = :rec_name, rec_ingredient = :rec_ingredient, rec_description = :rec_description where rec_id = :rec_id";
				$stmt = $this->dbConn->prepare($query);
				$stmt->execute($params);
			} catch (PDOException $e) { $this->db->getError($e); }
		}
		
		public function deleteFromDB() {
			try {
				$stmt = $this->dbConn->prepare("delete from recipes where rec_id = :id");
				$stmt->execute(array('id' => $this->rec_id));
			} catch (PDOException $e) { $this->db->getError($e); }
		}
		
		public function isNotEmpty() { return isset($this->rec_id); }
		
		// Gets
		public function getRecipeId() { return $this->rec_id; }
		public function getRecipeUserId() { return $this->rec_usr_id; }
		public function getRecipeUserFullName() { return $this->user->getUserFullName(); }
		public function getRecipeBoletuId() { return $this->rec_bol_id; }
		public function getRecipeBoletuName() { return $this->boletu->getBoletuName(); }
		public function getRecipeBoletuFullName() { return $this->boletu->getBoletuFullName(); }
		public function getRecipeDate() { return $this->rec_date; }
		public function getRecipeName() { return $this->rec_name; }
		public function getRecipeIngredient() { return $this->rec_ingredient; }
		public function getRecipeDescription() { return $this->rec_description; }
		
		// Sets
		public function setRecipeId($value) { $this->rec_id = $value; }
		public function setRecipeBoletuId($value) { $this->rec_bol_id = $value; }
		public function setRecipeDate($day, $month, $year) { $this->rec_date = array($day, $month, $year); }
		public function setRecipeName($value) { $this->rec_name = $value; }
		public function setRecipeIngredient($value) { $this->rec_ingredient = $value; }
		public function setRecipeDescription($value) { $this->rec_description = $value; }
		
		protected function fill(array $row) {
			foreach ($row as $propName => $propValue) $this->{$propName} = $propValue;
		}
	}
	
?>