<?
	/**
	 *	Title: Classe Support, s'encarrega d'obtenir valors de les taules de sistema i suport des d'un únic punt.
	 *
	 *	Project: iBoletus
	 *	Author: Victor Llorente Vaquero
	 *	Date: 18/11/2013
	 *	Email: vllorente@uoc.edu
	 **/
		
	class Support {
		
		private $db = null;
		private $dbConn = null;
	
		public function __construct() {
			$this->db = new Database();
			$this->dbConn = $this->db->getDB();
		}
			
		public function getSearchModules(){
			try {
				$stmt = $this->dbConn->query("select sys_description, sys_value from system where sys_type = 'module' order by sys_description");
			} catch (PDOException $e) { $this->db->getError($e); }
	
			return $stmt->fetchAll();
		}
	
		public function getRoleNameById($id) {
			try {
				$stmt = $this->dbConn->prepare("select rol_role_name from roles where rol_role_id = :id limit 1");
				$stmt->execute(array('id' => $id));
				$row = $stmt->fetch();
			} catch (PDOException $e) { $this->db->getError($e); }
	
			return $row['rol_role_name'];
		}
		
		public function getSupportValueById($id) {
			try {
				$stmt = $this->dbConn->prepare("select sup_description from support where sup_id = :id limit 1");
				$stmt->execute(array('id' => $id));
				$row = $stmt->fetch();
			} catch (PDOException $e) { $this->db->getError($e); }
			
			return $row['sup_description'];
		}
		
		public function getSystemValueByType($type, $value) {
			try {
				$stmt = $this->dbConn->prepare("select sys_description from system where sys_type = :type and sys_value = :value limit 1");
				$stmt->execute(array('type' => $type, 'value' => $value));
				$row = $stmt->fetch();
			} catch (PDOException $e) { $this->db->getError($e); }
			
			return $row['sys_description'];
		}
		
		public function getSystemArrayByType($type, $value) {
			try {
				$stmt = $this->dbConn->prepare("select sys_value, sys_description from system where sys_type = :type order by sys_description");
				$stmt->execute(array('type' => $type));
			} catch (PDOException $e) { $this->db->getError($e); }
			
			$result = array();			
			while ($row = $stmt->fetch()) {
				if (in_array($row[0], $value)) array_push($result, $row['sys_description']);
			}
			
			return $result;
		}
	
		public function getValuesArray($define_table, $type = "") {
			switch ($define_table) {
				case TABLE_SYSTEM: $fields = "sys_value, sys_description"; $table = "system"; $where = "sys_type"; $order = "sys_description"; break;
				case TABLE_SUPPORT: $fields = "sup_id, sup_description"; $table = "support"; $where = "sup_type"; $order = "sup_description"; break;
				case TABLE_ROLES: $fields = "*"; $table = "roles"; $where = "1"; $type = "1"; $order = "rol_role_name"; break;
			}
	
			try {
				$stmt = $this->dbConn->prepare("select $fields from $table where $where = :type order by $order");
				$stmt->execute(array('type' => $type));
			} catch (PDOException $e) { $this->db->getError($e); }
				
			return $stmt->fetchAll();
		}

		protected function fill(array $row){
			foreach ($row as $propName => $propValue) $this->{$propName} = $propValue;
		}
	}
		
?>
