<?
	/**
	 *	Title: Classe Token, model per a un token.
	 *
	 *	Project: iBoletus
	 *	Author: Victor Llorente Vaquero
	 *	Date: 05/12/2013
	 *	Email: vllorente@uoc.edu
	 **/
	
	class Token {
	
		private $tok_id;
		private $tok_usr_id;
		private $tok_num;
		private $tok_date_created;
				
		private $db = null;
		private $dbConn = null;
		
		public function __construct($db) {
			$this->db = $db;
			$this->dbConn = $this->db->getDB();
		}
		
		public function initWithId($id) {
			try {
				$stmt = $this->dbConn->prepare("select * from tokens where tok_id = :id limit 1");
				$stmt->execute(array('id' => $id));
			} catch (PDOException $e) { $this->db->getError($e); }
			
			if ($stmt->rowCount() == 1) {
				$this->fill($stmt->fetch());
				$this->convertDates();
			}
		}
		
		protected function convertDates() {
			$this->tok_date_created = format_date_array($this->tok_date_created);
		}
		
		public function initWithArray(array $data) {
			if (is_array($data) && !empty($data)) $this->fill($data);
		}
	
		public function saveToDB(){
			try {
				$stmt = $this->dbConn->prepare("insert into tokens (tok_usr_id, tok_num, tok_date_created) values (:tok_usr_id, :tok_num, NOW())");
				$stmt->execute(array('tok_usr_id' => $_SESSION[info_user][id], 'tok_num' => genCode(32)));
				$id = $this->dbConn->lastInsertId();
			} catch (PDOException $e) { $this->db->getError($e); }
			
			return $id;
		}
		
		public function deleteFromDB() {
			try {
				$stmt = $this->dbConn->prepare("delete from tokens where tok_id = :id");
				$stmt->execute(array('id' => $this->tok_id));
			} catch (PDOException $e) { $this->db->getError($e); }
		}
		
		// Retorna el identificador del registre de la BD per a un usuari i un número de token
		public function tokenId($usr_id, $tok_num) {
			try {
				$stmt = $this->dbConn->prepare("select tok_id from tokens where tok_usr_id = :usr_id and tok_num = :tok_num limit 1");
				$stmt->execute(array('usr_id' => $usr_id, 'tok_num' => $tok_num));
			} catch (PDOException $e) { $this->db->getError($e); }
			
			foreach ($stmt->fetchAll() as $token) {
				return $token['tok_id'];
			}
		}
		
		// Retorna l'usuari que ha generat el token
		public function checkToken($tok_num) {
			try {
				$stmt = $this->dbConn->prepare("select tok_usr_id from tokens where tok_num = :tok_num limit 1");
				$stmt->execute(array('tok_num' => $tok_num));
			} catch (PDOException $e) { $this->db->getError($e); }
			
			foreach ($stmt->fetchAll() as $token) {
				return $token['tok_usr_id'];
			}
		}
		
		// Gets
		public function getTokenId() { return $this->tok_id; }
		public function getTokenUserId() { return $this->tok_usr_id; }
		public function getTokenNum() { return $this->tok_num; }
		public function getTokenDateCreated() { return $this->tok_date_created; }
		
		// Sets
		public function settokenNum($value) { $this->tok_num = $value; }
		
		protected function fill(array $row){
			foreach ($row as $propName => $propValue) $this->{$propName} = $propValue;
		}
	}
	
?>