<?
	/**
	 *	Title: Classe User, model per a un usuari.
	 *
	 *	Project: iBoletus
	 *	Author: Victor Llorente Vaquero
	 *	Date: 18/11/2013
	 *	Email: vllorente@uoc.edu
	 **/
	
	class User {
	
		private $usr_id;
		private $usr_user;
		private $usr_password;
		private $usr_name;
		private $usr_first_last_name;
		private $usr_second_last_name;
		private $usr_gender;
		private $usr_country;
		private $usr_phone;
		private $usr_email;
		private $usr_date_created;
		private $usr_role;
		
		private $db = null;
		private $dbConn = null;
		
		public function __construct($db) {
			$this->db = $db;
			$this->dbConn = $this->db->getDB();
		}
				
		public function initWithUsername($username) {
			try {
				$stmt = $this->dbConn->prepare("select * from users where usr_user = :username limit 1");
				$stmt->execute(array('username' => $username));
			} catch (PDOException $e) { $this->db->getError($e); }
						
			if ($stmt->rowCount() == 1) {
				$this->fill($stmt->fetch());
				$this->convertDates();		
			}
		}
		
		protected function convertDates(){
			$this->usr_date_created = format_date_array($this->usr_date_created);
		}
		
		public function initWithId($id) {
			try {
				$stmt = $this->dbConn->prepare("select * from users where usr_id = :id limit 1");
				$stmt->execute(array('id' => $id));
			} catch (PDOException $e) { $this->db->getError($e); }
			
			if ($stmt->rowCount() == 1) $this->fill($stmt->fetch());		
		}
		
		public function initWithArray(array $data) {
			if (is_array($data) && !empty($data)) $this->fill($data);
		}
	
		public function saveToDB(){
			try {
				$stmt = $this->dbConn->prepare("insert into users (usr_name, usr_first_last_name, usr_second_last_name, usr_gender, usr_country, usr_phone, usr_email, usr_date_created, usr_user, usr_password, usr_role) values (:usr_name, :usr_first_last_name, :usr_second_last_name, :usr_gender, :usr_country, :usr_phone, :usr_email, NOW(), :usr_user, :usr_password, :usr_role)");
				$stmt->execute(array('usr_name' => $this->usr_name, 'usr_first_last_name' => $this->usr_first_last_name, 'usr_second_last_name' => $this->usr_second_last_name, 'usr_gender' => $this->usr_gender, 'usr_country' => $this->usr_country, 'usr_phone' => $this->usr_phone, 'usr_email' => $this->usr_email, 'usr_user' => $this->usr_user, 'usr_password' => $this->usr_password, 'usr_role' => $this->usr_role));
				$id = $this->dbConn->lastInsertId();
			} catch (PDOException $e) { $this->db->getError($e); }
			
			return $id;
		}

		public function updateInDB($password = false){
			try {
				$params = array('usr_name' => $this->usr_name, 'usr_first_last_name' => $this->usr_first_last_name, 'usr_second_last_name' => $this->usr_second_last_name, 'usr_gender' => $this->usr_gender, 'usr_country' => $this->usr_country, 'usr_phone' => $this->usr_phone, 'usr_email' => $this->usr_email, 'usr_user' => $this->usr_user, 'usr_role' => $this->usr_role, 'usr_id' => $this->usr_id);
				if ($password) {
					$queryModPassword = ", usr_password = :usr_password";
					$params['usr_password'] = $this->usr_password;
				} else {
					$queryModPassword = "";
				}
				$query = "update users set usr_name = :usr_name, usr_first_last_name = :usr_first_last_name, usr_second_last_name = :usr_second_last_name, usr_gender = :usr_gender, usr_country = :usr_country, usr_phone = :usr_phone, usr_email = :usr_email, usr_user = :usr_user".$queryModPassword.", usr_role = :usr_role where usr_id = :usr_id";
				$stmt = $this->dbConn->prepare($query);
				$stmt->execute($params);
			} catch (PDOException $e) { $this->db->getError($e); }
		}
		
		public function deleteFromDB(){
			try {
				$stmt = $this->dbConn->prepare("delete from positions where pos_usr_id = :id");
				$stmt->execute(array('id' => $this->usr_id));
				
				$stmt = $this->dbConn->prepare("delete from tokens where tok_usr_id = :id");
				$stmt->execute(array('id' => $this->usr_id));
				
				$stmt = $this->dbConn->prepare("delete from users where usr_id = :id");
				$stmt->execute(array('id' => $this->usr_id));
			} catch (PDOException $e) { $this->db->getError($e); }
		}
		
		public function isNotEmpty() { return isset($this->usr_id); }
		
		public function getUserId() { return $this->usr_id; }
		public function getUserUsername() { return $this->usr_user; }
		public function getUserName() { return $this->usr_name; }
		public function getUserFirstLastName() { return $this->usr_first_last_name; }
		public function getUserSecondLastName() { return $this->usr_second_last_name; }
		public function getUserFullName() {	return $this->usr_name." ".$this->usr_first_last_name." ".$this->usr_second_last_name; }
		public function getUserFullNameList() {
			if (!$this->usr_second_last_name)
				return $this->usr_first_last_name.", ".$this->usr_name;
			else
				return $this->usr_first_last_name." ".$this->usr_second_last_name.", ".$this->usr_name;
		}
		public function getUserGender() { return $this->usr_gender; }
		public function getUserCountry() { return $this->usr_country; }
		public function getUserPhone() { return $this->usr_phone; }
		public function getUserEmail() { return $this->usr_email; }
		public function getUserDateCreated() { return $this->usr_date_created; }
		public function getUserRole() { return $this->usr_role; }

		public function setUserId($value) { $this->usr_id = $value; }
		public function setUserUsername($value) { $this->usr_user = $value; }
		public function setUserPassword($value) { $this->usr_password = $value; }
		public function setUserName($value) { $this->usr_name = $value; }
		public function setUserFirstLastName($value) { $this->usr_first_last_name = $value; }
		public function setUserSecondLastName($value) { $this->usr_second_last_name = $value; }
		public function setUserGender($value) { $this->usr_gender = $value; }
		public function setUserCountry($value) { $this->usr_country = $value; }
		public function setUserPhone($value) { $this->usr_phone = $value; }
		public function setUserEmail($value) { $this->usr_email = $value; }
		public function setUserRole($value) { $this->usr_role = $value; }
		
		public function authenticate($username, $password) {
			return ($this->usr_user == $username) && ($this->usr_password == sha1($password));
		}
	
		public function setSession() {
			$_SESSION['info_user'] = array('ip' => $_SERVER['REMOTE_ADDR'], 'id' => $this->usr_id, 'user' => $this->usr_user, 'name' => $this->usr_name." ".$this->usr_first_last_name." ".$this->usr_second_last_name, 'role' => $this->usr_role);
		}
		
		protected function fill(array $row){
			foreach ($row as $propName => $propValue) $this->{$propName} = $propValue;
		}
	}
	
?>