<?
	/**
	 *	Title: Classe Validator, per validar dades entrades en un formulari.
	 *
	 *	Project: iBoletus
	 *	Author: Victor Llorente Vaquero
	 *	Date: 18/11/2013
	 *	Email: vllorente@uoc.edu
	 **/
	
	class Validator {
		
		private $db = null;
		private $dbConn = null;
		
		private $form = array();		
		private $formRestrictions = array();
		private $formErrors = array();
		private $valid = true;
		
		private function regexpText($text) { return preg_match("/^[-,.\'\·\ \:a-zA-ZàÀáÁâÂãÄäÄèÈéÉêÊëËìÌíÍîÎïÏòÒóÓôÔöÖõùÙúÚûÛüÜñÑçÇ]+$/", $text); }
		private function regexpTextNumber($text_num) { return preg_match("/^[-,.\'\ \·\.\_\/\:\;a-zA-ZàÀáÁâÂãÄäÄèÈéÉêÊëËìÌíÍîÎïÏòÒóÓôÔöÖõùÙúÚûÛüÜñÑçÇ0-9¿?¡!%()]+$/", $text_num); }
		private function regexpNumber($num) { return preg_match('/^[0-9]+$/', $num); }
		private function regexpNumberDecimal($num) { return (preg_match('/^[0-9]+\.[0-9]+$/', $num) || preg_match('/^[0-9]+$/', $num)); }
		private function regexpNumberDecimalComa($num) { return (preg_match('/^[0-9\.]+\,[0-9]+$/', $num) || preg_match('/^[0-9\.]+$/', $num)); }
		private function regexpDate_ddmmmyyyy($date) { return (preg_match('/^(0[1-9]|[12][0-9]|3[01])[\/](0[1-9]|1[012])[\/](19|20)\d\d$/', $date) || preg_match('/^(0[1-9]|1[012])[\/](19|20)\d\d$/', $date)); }
		private function regexpDate_yyyymmdd($date) { return (preg_match('/^(19|20)[\/](0[1-9]|1[012])[\/](0[1-9]|[12][0-9]|3[01])\d\d$/', $date) || preg_match('/^(19|20)[\/](0[1-9]|1[012])\d\d$/', $date)); }
		private function regexpUsername($user) { return preg_match("/^[a-z0-9]+$/", $user); }
		private function regexpPhoneFax($pf) { return preg_match('/^[0-9\+\(\)\-\ \(ext)\.]+$/', $pf); }
		private function regexpId($id) { return preg_match("/^[A-Z0-9]+$/", $id); }
		private function regexpIdToken($id_token) { return preg_match("/^[A-Z0-9]{32}+$/", $id_token); }
		private function regexpPassword($password) { return preg_match("/^[a-zA-Z0-9]+$/", $password); }
		private function regexpBool($bool) { return preg_match("/^[0-1]$/", $bool); }
		private function regexpEmail($em) { return preg_match('/^[a-zA-Z0-9_\-\.]+@[a-zA-Z0-9\-]+\.[a-zA-Z0-9\-\.]+$/', $em); }
		private function regexpDate($date) { return preg_match('/^(0?[1-9]|[12][0-9]|3[01])[\/\-](0?[1-9]|1[012])[\/\-]\d{4}$/', $date); }
		
		
		public function __construct(array $data) {
			$this->form = $data;
			$this->db = new Database();
			$this->dbConn = $this->db->getDB();
		}
		
		// Substituir els caràcters no acceptats per un guió baix, i tots els possibles guions baix per un de sol
		public function replaceChars($doc_name) {
			return preg_replace('/\_+/', '_', str_replace(array("#", "$", "%", "^", "&", "*", "?", "¿", "@", "~", "ª", "º", "|", "!", "¡", "·", "¬", "/", "(", ")", "=", "'", "½", "[", "]", " ", ",", ";", "-", "{", "}"), "_", $doc_name));
		}
		
		public function getError($value) { return $this->formErrors[$value]; }
		public function setError($value, $error) { $this->formErrors[$value] = $error; $this->valid = false;}
		public function isFormValid(){ return $this->valid; }
		
		public function setRestriction($name, $regexp, $mandatory = false) {
			$this->formRestrictions[$name] = array($regexp, $mandatory);
		}
		
		public function setTest($test, $regexp, $mandatory, $extra) {
			switch ($test) {
				case TEST_CHECK:
				case TEST_DATE:
				case TEST_FILE:
					$this->formRestrictions[$extra] = array($regexp, $mandatory, $test, $extra);
					break;
				case TEST_SELECT:
					$this->formRestrictions[$extra[0]] = array($regexp, $mandatory, $test, $extra);
					break;
				case TEST_PASSWORD:
					$this->formRestrictions[$extra[0]] = array($regexp, $mandatory, $test, $extra);
					$this->formRestrictions[$extra[1]] = array($regexp, $mandatory, $test, $extra);
					break;
			}
		}
		
		public function getFormEntry($value, $lenght = MAX_INPUT) {
			if (!is_array($this->form[$value])) return trim(substr($this->form[$value], 0, $lenght)); else return $this->form[$value];
		}
		
		public function validate() {
			$valid = true;
			
			// TEST: REGEXP
			// Verifiquem primer que tots els regexp siguin vàlids
			foreach ($this->formRestrictions as $key => $value) {
				$re_error = false;
				
				switch ($value[0]) {
					case RE_ANY: break;
					case RE_ALFA: if (!$this->regexpText($this->form[$key])) $re_error = true; break;
					case RE_ALFANUM: if (!$this->regexpTextNumber($this->form[$key])) $re_error = true; break;
					case RE_NUM: if (!$this->regexpNumber($this->form[$key])) $re_error = true; break;
					case RE_NUM_DEC: if (!$this->regexpNumberDecimal($this->form[$key])) $re_error = true; break;
					case RE_NUM_DEC_COMA: if (!$this->regexpNumberDecimalComa($this->form[$key])) $re_error = true; break;
					case RE_DATE_FW: if (!$this->regexpDate_ddmmmyyyy($this->form[$key])) $re_error = true; break;
					case RE_DATE_BW: if (!$this->regexpDate_yyyymmdd($this->form[$key])) $re_error = true; break;
					case RE_USERNAME: if (!$this->regexpUsername($this->form[$key])) $re_error = true; break;
					case RE_PHONE: if (!$this->regexpPhoneFax($this->form[$key])) $re_error = true; break;
					case RE_ID: if (!$this->regexpId($this->form[$key])) $re_error = true; break;
					case RE_ID_TOKEN: if (!$this->regexpIdToken($this->form[$key])) $re_error = true; break;
					case RE_PASSWORD: if (!$this->regexpPassword($this->form[$key])) $re_error = true; break;
					case RE_BOOL: if (!$this->regexpBool($this->form[$key])) $re_error = true; break;
					case RE_EMAIL: if (!$this->regexpEmail($this->form[$key])) $re_error = true; break;
				}
				
				if ((!(isset($value[2]) && $value[2] == TEST_CHECK && isset($this->form[$key]))) && (!(isset($value[2]) && $value[2] == TEST_SELECT && $this->form[$key] == "-1")) && (!(isset($value[2]) && $value[2] == TEST_FILE && isset($this->form[$key]))) && $this->form[$key] != "" && $re_error) { $this->formErrors[$key] = INPUT_INVALID; $valid = false; }
				
			}

			// TEST: SELECT
			// Verifiquem que tots els valors dels desplegables siguin vàlids
			foreach ($this->formRestrictions as $key => $value) {
				if (isset($value[2]) && $value[2] == TEST_SELECT) {
					if ($this->form[$key] != "-1") {
						try {
							switch ($value[3][1]) {
								case TABLE_BOLETUS: $sql = "select bol_id from boletus where bol_id = :value limit 1"; break;
								case TABLE_RECIPES: $sql = "select rec_id from recipes where rec_id = :value limit 1"; break;
								case TABLE_ROLES: $sql = "select rol_role_id from roles where rol_role_id = :value limit 1"; break;
								case TABLE_SUPPORT: $sql = "select sup_id from support where sup_id = :value and sup_type = '".$value[3][2]."' limit 1"; break;
								case TABLE_SYSTEM: $sql = "select sys_value from system where sys_value = :value and sys_type = '".$value[3][2]."' limit 1"; break;
								case TABLE_USERS: $sql = "select usr_id from users where usr_id = :value limit 1"; break;
							}
							$stmt = $this->dbConn->prepare($sql);
							$stmt->execute(array('value' => $this->form[$key]));				
						} catch (PDOException $e) { $this->db->getError($e); }
						
						if ($stmt->rowCount() == 0) { $this->formErrors[$key] = INPUT_INVALID; $valid = false; }
					}
				}
			}
			
			// TEST: CHECK
			// Verifiquem que tots els valors dels checkboxs siguin vàlids
			foreach ($this->formRestrictions as $key => $value) {
				if (isset($value[2]) && $value[2] == TEST_CHECK && isset($this->form[$key])) {
					try {
						foreach ($this->form[$key] as $c) {
							$sql = "select sys_value from system where sys_value = :value and sys_type = :sys_type limit 1";
							$stmt = $this->dbConn->prepare($sql);
							$stmt->execute(array('value' => $c, 'sys_type' => $value[3]));
							if ($stmt->rowCount() == 0) { $this->formErrors[$key] = INPUT_INVALID; $valid = false; }
						}
					} catch (PDOException $e) { $this->db->getError($e); }
				}
			}
			
			// TEST: FILE
			// Verifiquem que tots els valors siguin vàlids
			foreach ($this->formRestrictions as $key => $value) {
				if (isset($value[2]) && $value[2] == TEST_FILE && isset($this->form[$key])) {
					if (!$this->regexpTextNumber($this->replaceChars($this->form[$key]['name']))) { $this->formErrors[$value[3]] = INPUT_INVALID; $valid = false; }
				}
			}

			// TEST: PASSWORD
			// Verifiquem que dos camps de contrasenya siguin iguals i que la mida mínima sigui de MIN_PASS_LENGHT caràcters 
			foreach ($this->formRestrictions as $key => $value) {
				if (isset($value[2]) && $value[2] == TEST_PASSWORD) {
					if (($this->form[$value[3][0]] != $this->form[$value[3][1]]) || (strlen($this->form[$value[3][0]]) < MIN_PASS_LENGTH)) { $this->formErrors[$key] = INPUT_INVALID; $valid = false; }
				}
			}
			
			// TEST: DATE
			// Verifiquem que el día, mes i any per als valors dels desplegables siguin vàlids
			foreach ($this->formRestrictions as $key => $value) {
				if (isset($value[2]) && $value[2] == TEST_DATE) {
					if ($this->form["day_".$value[3]] != '-1' || $this->form["month_".$value[3]] != '-1' || $this->form["year_".$value[3]] != '-1') {
						if (!$this->regexpDate($this->form["day_".$value[3]]."/".$this->form["month_".$value[3]]."/".$this->form["year_".$value[3]])) { $this->formErrors[$value[3]] = INPUT_INVALID; $valid = false; }
					}
				}
			}

			// TEST: EMPTY
			// Verifiquem que tots els valors obligatoris continguin algun valor
			foreach ($this->formRestrictions as $key => $value) {
				switch ($value[2]) {
					case TEST_SELECT: if ($value[1] && $this->form[$key] == "-1") { $this->formErrors[$key] = INPUT_EMPTY; $valid = false;} break;
					case TEST_DATE: if ($value[1] && $this->form["day_".$value[3]] == '-1' && $this->form["month_".$value[3]] == '-1' && $this->form["year_".$value[3]] == '-1') { $this->formErrors[$value[3]] = INPUT_EMPTY; $valid = false; } break;
					case TEST_FILE: if ($value[1] && $this->form[$key]['name'] == "") { $this->formErrors[$key] = INPUT_EMPTY; $valid = false; } break;
					default: if ($value[1] && $this->form[$key] == "") { $this->formErrors[$key] = INPUT_EMPTY; $valid = false; } break;
				}
			}
			
			$this->valid = $valid;
		}
		
		public function getForm(){ return $this->form; }
		public function getRestrictions(){ return $this->formRestrictions; }
		public function getErrors(){ return $this->formErrors; }
		
		public function dumpVars() { return "FORM: ".print_r($this->form, true)."<br><br>RESTRICTIONS: ".print_r($this->formRestrictions, true)."<br><br>ERRORS: ".print_r($this->formErrors, true); } 
	}

?>