<?
	/**
	*	Title: Arxiu amb les funcions globals (utilitzades per més d'un mòdul)
	*
	*	Project: iBoletus
	*	Author: Victor Llorente Vaquero
	*	Date: 18/11/2013
	*	Email: vllorente@uoc.edu
	**/

	function __autoload($class_name) {
	    if (file_exists(DIRCLASSES."/".$class_name.".php")) require_once (DIRCLASSES."/".$class_name.".php");
	}

	///////////////////////////////////////////////////
	// Funcions de tractament de valors de formulari //
	///////////////////////////////////////////////////

	// Funcións de neteja per a valor de formularis
	function ht($str) { return htmlspecialchars($str); }

	// Funció que fa un number format d'acord amb les especificacions de l'aplicació.
	function nf($value, $decimals) { if (!empty($value)) return number_format($value, $decimals, ',', '.'); else return $value; }
	function fn($value) { return preg_replace('/\,/', '.', preg_replace('/\./', '', $value)); }
	
	//////////////////
	// Generar codi //
	//////////////////
	function genCode($len) {
		$chars = "ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789";
		if ($len > 0) {
			$code="";
			for ($i=1; $i<=$len; $i++) {
				$num = mt_rand(0,35);
				$code .= substr($chars, $num, 1);
			}
		}
		return $code;
	}
	
	/////////////////////
	// Gestió de dates //
	/////////////////////

	// Funció per mostrar la data en el següent format 
	// Dimarts, 29 d'octubre del 2009
	// NOTA : strtotime() converteix de ISO8601 a timestamp
	function format_date($d) {
		if ($d != NULL) {
			$month = strftime("%B", strtotime($d));
			switch ($month) {
				case "abril":
				case "agost":
				case "octubre":
					$m_apos = "d'";	break;
				default: $m_apos = "de "; break;
			}			
			return strftime (_("%A, %e $m_apos%B del %Y"), strtotime($d));
		} else {
			return "";
		}
	}

	// Funció per mostrar la data en el següent format 
	// Dimarts, 29 d'octubre del 2009
	// NOTA : strtotime() converteix de ISO8601 a timestamp
	function format_date_simple($d) {
		$month = strftime("%B", strtotime($d));
		switch ($month) {
			case "abril":
			case "agost":
			case "octubre":
				$m_apos = "d'";	break;
			default: $m_apos = "de "; break;
		}			
		return strftime (_("%e $m_apos%B del %Y"), strtotime($d));
	}

	// Funció per mostrar la data en el següent format 
	// 29/10/2009
	// NOTA : strtotime() converteix de ISO8601 a timestamp
	function format_date_number($d) { 
		if ($d != NULL) 
			return strftime (_("%d/%m/%Y"), strtotime($d)); 
		else 
			return "";
	}
	
	// Funció per mostrar la data en el següent format 
	// Dimarts, 29 d'octubre del 2009, a les 04:00 hores.
	// NOTA : strtotime() converteix de ISO8601 a timestamp
	function format_date_hour($d) {
		$month = strftime("%B", strtotime($d));
		switch ($month) {
			case "abril":
			case "agost":
			case "octubre":
				$m_apos = "d'";	break;
			default: $m_apos = "de "; break;
		}
		
		$hour = strftime("%H", strtotime($d));
		switch ($hour) {
			case "01":
				$h_apos = "l'"; break;
			default: $h_apos = "les "; break;				
		}
			
		return strftime (_("%A, %e $m_apos%B del %Y, a $h_apos%H:%M hores"), strtotime($d));
	}
	
	// Funció per mostrar la data en el següent format 
	// 29.10.09
	// NOTA : strtotime() converteix de ISO8601 a timestamp
	function format_date_dots($d) { 
		if ($d != NULL) 
			return strftime (_("%d.%m.%y"), strtotime($d)); 
		else 
			return "";
	}
	
	// Retorna la data en una array
	function format_date_array($date) {
		if ($date != NULL) {
			return array(strftime("%d", strtotime($date)), strftime("%m", strtotime($date)), strftime("%Y", strtotime($date)));
		} else {
			return array(-1, -1, -1);
		}		
	}
	
	// Retorna la data i l'hora en una array
	function format_datetime_array($datetime) {
		if ($datetime != NULL) {
			return array(strftime("%d", strtotime($datetime)), strftime("%m", strtotime($datetime)), strftime("%Y", strtotime($datetime)), strftime("%H", strtotime($datetime)), strftime("%M", strtotime($datetime)), strftime("%S", strtotime($datetime)));
		} else {
			return array(-1, -1, -1, -1, -1, -1);
		}
	}
	
	// Transforma la data de l'array en una data en timestamp
	function get_ISO_date(array $date) {
		if ($date[0] != -1 && $date[1] != -1 && $date[2] != -1)
			return date ("c", mktime (0, 0, 0, $date[1], $date[0], $date[2]));
		else
			return NULL;
	}
	
	// Transforma la data i hora de l'array en una data i hora en timestamp
	function get_ISO_datetime(array $datetime) {
		if ($datetime[0] != -1 && $datetime[1] != -1 && $datetime[2] != -1 && $datetime[3] != -1 && $datetime[4] != -1 && $datetime[5] != -1)
			return date ("c", mktime($datetime[3], $datetime[4], $datetime[5], $datetime[1], $datetime[0], $datetime[2]));
		else
			return NULL;
	}
	
	// Comparar dues dates, per a determinar quina es superior
	function compareTwoDates($start_date, $end_date) {
		if (strtotime(get_ISO_date($start_date)) > strtotime(get_ISO_date($end_date))) return true; else return false;
	}
	
	// Comprovar si la data es buida
	function emptyDate($date) {
		if ($date[0] != -1 && $date[1] != -1 && $date[2] != -1) return true; else return false;
	}
	
	// Mostrar codi Iban separat per agrupacions de 4 caràcters
	function showIbanCode($iban) {
		$count = 0;
		for ($i = 0; $i < strlen($iban); $i++) {
  			$iban_code .= $iban[$i];
  			$count++;
  			
  			if ($count == 4) { $iban_code .= " "; $count = 0; }
		}
		return $iban_code;
	}
	
	// Funció per afegir un nou document addicional al directori '/var/iboletusdata/...'
	function add_document($module, $folder, $file, $document) {
		
		$log = new Logger();
		$sm = new Security();
		$err = new Error();
		
		if ($sm->hasPermission('new_folder') && $sm->hasPermission('new_document')) {
			
			// Comprovar l'extensió de l'arxiu, l'extensió acceptada serà 'pdf'
			$mime_types = array("application/pdf");
		 	$mime = mime_content_type($file['doc']['tmp_name']);
		 	if (!in_array($mime, $mime_types)) $error = true;
		 	
		 	// Comprovar la mida de l'arxiu que és vol pujar, com a màxim 200KB
			if ($file['doc']['size'] > MAX_FILE_SIZE) $error = true;
			
			if (!$error) {
				// Crear la carpeta en cas de no existir
				if (!file_exists(DIRDATA."/".$module."/".$folder."/")) {
					
					// Crear la carpeta per afegir els documents, el nom correspon al identificador del registre
					if (!mkdir(DIRDATA."/".$module."/".$folder, 0755)) {
						$log->logAction('create_folder_error');
						$err->showError(ERROR_CREATE_FOLDER);
					}
					$log->logAction('add_folder');
				}
				
				// Desar el document addicional, a la carpeta anteriorment creada, sempre que no existeixi cap altre document amb el mateix nom i extensió a la carpeta
				if (!file_exists(DIRDATA."/".$module."/".$folder."/".$document)) {
					if (!move_uploaded_file($file['doc']['tmp_name'], DIRDATA."/".$module."/".$folder."/".basename($document))) {
						$log->logAction('upload_file_error');
						$err->showError(ERROR_UPLOAD);
					} else {
						$log->logAction('add_document');
					}
				} else {
					$error = true;
				}
			}
		}
		
		return $error;
	}
	
	// Eliminar un document adjunt del directori '/var/iboletusdata/...' corresponen amb un mòdul i un identificador en concret
	function remove_document($module, $folder, $document) {
		
		$log = new Logger();
		$sm = new Security();
		
		if ($sm->hasPermission('remove_document')) {
			if (file_exists(DIRDATA."/".$module."/".$folder."/".$document)) {
				unlink(DIRDATA."/".$module."/".$folder."/".$document); 
			}
			$log->logAction('delete_document');
		}
	}
	
	// Eliminar documents adjunts del directori '/var/iboletusdata/...' corresponen amb un mòdul i un identificador en concret
	function remove_documents($module, $folder) {
		
		$log = new Logger();
		$sm = new Security();
		
		if ($sm->hasPermission('remove_document')) {
			echo DIRDATA."/".$module."/".$folder."/";
			if (file_exists(DIRDATA."/".$module."/".$folder."/")) {
				$d = dir(DIRDATA."/".$module."/".$folder."/");
				while ($entry = $d->read()) {
					// Eliminar un arxiu 
					if ($entry != "." && $entry != "..") {
						unlink(DIRDATA."/".$module."/".$folder."/".$entry);
						$log->logAction('delete_document');
					}
				} 
				$d->close();
			}
		}
	}
	
	// Eliminar una carpeta del directori '/var/iboletusdata/...' corresponen amb un mòdul i un identificador en concret
	function remove_folder($module, $folder) {
		
		$log = new Logger();
		$sm = new Security();
		
		if ($sm->hasPermission('remove_folder')) {
			if (file_exists(DIRDATA."/".$module."/".$folder."/")) {
				rmdir(DIRDATA."/".$module."/".$folder."/");
			}
			$log->logAction('delete_folder');
		}
	}
	
	// Funció per visualitzar una fotografia
	// Retornar la direcció 'URL' amb els paràmetres de llargada i amplada per visualitzar la foto
	// És cridar als arxius on els mòduls que incorporen fotografia.
	// $module: mòdul
	// $id: identificador
	// $width: amplada
	// $height: alçada
	function view_photo($module, $id, $width, $height) {
		
		// En cas de tenir fotografia mostre'm la que correspon a l'usuari amb el seu identificador intern '.jpg'
		if (file_exists(DIRDATA."/".$module."/".$id.".jpg")) $photo = WWWROOT."/lib/photos.php?mod=".$module."&img=".$id.".jpg&w=".$width."&h=".$height;
		if (file_exists(DIRDATA."/".$module."/".$id.".jpeg")) $photo = WWWROOT."/lib/photos.php?mod=".$module."&img=".$id.".jpeg&w=".$width."&h=".$height;
		if (file_exists(DIRDATA."/".$module."/".$id.".png")) $photo = WWWROOT."/lib/photos.php?mod=".$module."&img=".$id.".png&w=".$width."&h=".$height;
		if (file_exists(DIRDATA."/".$module."/".$id.".gif")) $photo = WWWROOT."/lib/photos.php?mod=".$module."&img=".$id.".gif&w=".$width."&h=".$height;
		
		// En el cas de no disposar de fotografia, mostre'm una foto per defecte
		if (!$photo) { $photo = WWWROOT."/lib/photos.php?mod=".$module."&img=default.jpg&w=".$width."&h=".$height; }
		
		return $photo;
	}
	
	// Funció per afegir una nova fotografia, al directori '/var/iboletusdata/' i el nom del mòdul.
	// NOTA :
	// $_FILES['file']['tmp_name'] : el nom de l'arxiu temporal que es fara servir per emmagatzemar en el servidor l'arxiu rebut
	// $_FILES['file']['name'] : nom original de l'arxiu a la maquina client
	// $_FILES['file']['size'] : mida en bytes de l'arxiu rebut
	// $_FILES['file']['type'] : el tipus mime del fitxer (si el navegador o proporcionar), un exemple seria 'image/gif'
	function add_photo($file, $module, $id, $photo) {
		
		$log = new Logger();
		$sm = new Security();
		
		// Comprovar que les caracteristiques de l'arxiu són les correctes i enregistrar l'arxiu al folder
		if (!move_uploaded_file($file, DIRDATA."/".$module."/".basename($photo))) error_upload_file();
		$log->logAction('add_photo');
	
		// Obtenir la extensió del document
		$extension = explode(".", $photo);
		// NOTA : strtolower(string $str)
		// La funció transformar la 'string' que es pasa en una 'string' en minúscules.
		$extension = strtolower($extension[1]);
		
		// Renombrar l'arxiu que hem carregat abans
		rename(DIRDATA."/".$module."/".$photo, DIRDATA."/".$module."/".$id.".".$extension);
		$log->logAction('rename_photo');
	}
	
	// Funció per eliminar un arxiu, en aquest cas la fotografia del bolet, recepta, ..,
	// sempre i quan hi haguí fotografia a la carpeta '/var/iboletusdata/name_module/'.
	function remove_photo($module, $id) {
		
		$log = new Logger();
		$sm = new Security();
		
		$d = dir(DIRDATA."/".$module."/");
		while($entry = $d->read()) { 
			if ($entry != "." && $entry != "..") { 
				$extension = explode(".", $entry);
				if (file_exists(DIRDATA."/".$module."/".$id.".".$extension[1])) unlink(DIRDATA."/".$module."/".$id.".".$extension[1]);
			} 
		}
		$d->close();
		$log->logAction('delete_photo');
	}
	
?>