<?
	/**
	*	Title : Edició d'un usuari
	*
	*	Project: iBoletus
	*	Author: Victor Llorente Vaquero
	*	Date: 18/11/2013
	*	Email: vllorente@uoc.edu
	**/
	
	session_start();
	
	// Incloem les funcions
	require_once(dirname(__FILE__) . "/../../config.php");
	require_once(DIRLIB."/".APP.".php");

	$db = new Database();
	
	$r = new Redirector();
	$c = new Content();
	$log = new Logger();
	$sm = new Security();
	$err = new Error();
	$support = new Support();
	$detect = new MobileDetect();

	// Comprovar la sessió i els paràmetres d'entrada
	if (!$sm->isLogged()) { $log->logAction('session_error'); $r->loginRedirect(); }
	$sm->isIdValid($_GET['id'], 'users', 'usr_id') ? $usr_id = $_GET['id'] : $r->returnTo();
	
	// Comprovar els permisos
	if (!$sm->hasPermission('edit_users') && $usr_id != $_SESSION['info_user']['id']) $err->showError(ERROR_PERMISSION);
	
	$user = new User($db);
	$user->initWithId($usr_id);

	$fv = new Validator($_POST);
		
	// Accions amb botons
	if ($_POST['action']) { 
		switch($_POST['selected_action']) {
			case _("Desar"):
				
				$user->setUserName($fv->getFormEntry('name', 50));
				$user->setUserFirstLastName($fv->getFormEntry('first_last_name', 50));
				$user->setUserSecondLastName($fv->getFormEntry('second_last_name', 50));
				$user->setUserGender($fv->getFormEntry('gender', 1));
				$user->setUserCountry($fv->getFormEntry('country', 50));
				$user->setUserPhone($fv->getFormEntry('phone', 50));
				$user->setUserEmail($fv->getFormEntry('email', 50));
				$user->setUserUsername($fv->getFormEntry('username', 50));
				if ($fv->getFormEntry('pass1', 50)) { $user->setUserPassword(sha1($fv->getFormEntry('pass1', 50))); $modifyPassword = true; }
				$user->setUserRole($fv->getFormEntry('role'));
				
				$fv->setRestriction('name', RE_ALFA, true);
				$fv->setRestriction('first_last_name', RE_ALFA, true);
				$fv->setRestriction('second_last_name', RE_ALFA, true);
				$fv->setRestriction('phone', RE_PHONE);
				$fv->setRestriction('email', RE_EMAIL, true);
				$fv->setRestriction('username', RE_USERNAME, true);
				
				$fv->setTest(TEST_SELECT, RE_ID, false, array('gender', TABLE_SYSTEM, 'gender'));
				$fv->setTest(TEST_SELECT, RE_ID, false, array('country', TABLE_SYSTEM, 'country'));
				if ($sm->hasPermission('edit_users')) $fv->setTest(TEST_SELECT, RE_ID, true, array('role', TABLE_ROLES));
				if ($fv->getFormEntry('pass1')) $fv->setTest(TEST_PASSWORD, RE_PASSWORD, true, array('pass1', 'pass2'));
				
				$tmp_user = new User($db);
				$tmp_user->initWithUsername($username);
				if ($tmp_user->getUserId() && $tmp_user->getUserId() != $user->getUserId()) { $fv->setError('username', INPUT_REPEATED); }
				unset($tmp_user);

				$fv->validate();

				// En aquest punt es consideren les dades correctes i ja es poden desar a la base de dades.
				if ($fv->isFormValid()) {
					$user->updateInDB($modifyPassword);
					$log->logAction('edit_user');
					$r->redirect('users', 'view.php', array('id' => $usr_id));
				}
				break;
				
			case _("Sortir"):
				$r->redirect('users', 'view.php', array('id' => $usr_id));
				break;
		}
	}

	$gender = $support->getValuesArray(TABLE_SYSTEM, "gender");
	$country = $support->getValuesArray(TABLE_SYSTEM, 'country');
	$roles = $support->getValuesArray(TABLE_ROLES);
					
	// Preparació per la destrucció de les cookies de 'edit' i 'view'
	$cookie_view = preg_replace("/[\/\.]/", "", $_SERVER['PHP_SELF']);
	$cookie_edit = preg_replace("/view/", "edit", $cookie_view);
	
	// Inici creació de la pàgina
	$c->getHeader(_(APP_NAME));
	$c->getMainHeader(_("Editar usuari"));
	
?>
	
	<script>
		window.onload = function() {
			deleteCookie('<?= $cookie_view;?>', '/'); 
			deleteCookie('<?= $cookie_edit;?>', '/');
		}
	</script>

	<form class="global" name="form" accept-charset="UTF-8" method="post">
		<? if (!$detect->isMobile() && !$detect->isTablet()) { ?>
			<div class="actions">
				<? $c->getNavigation($_SERVER['PHP_SELF']); ?>
				<div class="options">
					<input title="<?=_('Desar')?>" class="button" type="submit" name="selected_action" value="<?=_('Desar')?>">
					<input title="<?=_('Sortir')?>" class="button" type="submit" name="selected_action" onClick="deleteCookie('<?=$cookie_view?>', '/'); deleteCookie('<?=$cookie_edit?>', '/');" value="<?=_('Sortir')?>">
				</div>
				<div class="clear"></div>
			</div>
		<? } ?>
		<? if (!$fv->isFormValid()) echo $c->getMessage(INFO_MESSAGE_INVALID_DATA, 1); ?>
		
		<div class="tabbed_box">
			<div class="content_section">
				<? $c->getSectionHeader("Dades personals"); ?>
				<? $c->getDiv("Nom:", $user->getUserName(), "name", EDIT_MODE, FIELD_TEXT, $fv->getError('name')); ?>
				<? $c->getDiv("Primer cognom:", $user->getUserFirstLastName(), "first_last_name", EDIT_MODE, FIELD_TEXT, $fv->getError('first_last_name')); ?>
				<? $c->getDiv("Segon cognom:", $user->getUserSecondLastName(), "second_last_name", EDIT_MODE, FIELD_TEXT, $fv->getError('second_last_name')); ?>
				<? $c->getDiv("Sexe:", $gender, "gender", EDIT_MODE, FIELD_SELECT, $fv->getError('gender'), $user->getUserGender())?>
				<? $c->getDiv("País:", $country, "country", EDIT_MODE, FIELD_SELECT, $fv->getError('country'), $user->getUserCountry()); ?>
				<? $c->getDiv("Telèfon:", $user->getUserPhone(), "phone", EDIT_MODE, FIELD_TEXT, $fv->getError('phone')); ?>
				<? $c->getDiv("Adreça electrònica:", $user->getUserEmail(), "email", EDIT_MODE, FIELD_EMAIL, $fv->getError('email')); ?>
				<? $c->getSectionHeader("Dades del compte"); ?>
				<? $c->getDiv("Nom d'usuari:", $user->getUserUsername(), "username", EDIT_MODE, FIELD_TEXT, $fv->getError('username')); ?>
				<? $c->getDiv("Contrasenya:", "", "pass1", EDIT_MODE, FIELD_PASSWORD, $fv->getError('pass1')); ?>
				<? $c->getDiv("Verificació de contrasenya:", "", "pass2", EDIT_MODE, FIELD_PASSWORD, $fv->getError('pass2')); ?>
				<? if ($sm->hasPermission('edit_users')) $c->getDiv("Perfil:", $roles, "role", EDIT_MODE, FIELD_SELECT, $fv->getError('role'), $user->getUserRole()); ?>
				<? if ($detect->isMobile() || $detect->isTablet()) { ?>
					<div class="options">
						<input title="<?=_('Desar')?>" class="button" type="submit" name="selected_action" value="<?=_('Desar')?>">
						<input title="<?=_('Sortir')?>" class="button" type="submit" name="selected_action" onClick="deleteCookie('<?=$cookie_view?>', '/'); deleteCookie('<?=$cookie_edit?>', '/');" value="<?=_('Sortir')?>">
					</div>
				<? } ?>
				<div class="clear"></div>
			</div>
		</div>
		<input type="hidden" name="action" value="1"/>
	</form>
	
<? $c->getFooter(); ?>
